# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/client_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/auth/client_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.auth import client_pb2 as eolymp_dot_auth_dot_client__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/auth/client_service.proto\x12\x0b\x65olymp.auth\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/auth/client.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"0\n\x10ListClientsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x11ListClientsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.auth.Client\"(\n\x13\x44\x65scribeClientInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\";\n\x14\x44\x65scribeClientOutput\x12#\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x13.eolymp.auth.Client\"8\n\x11\x43reateClientInput\x12#\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x13.eolymp.auth.Client\"7\n\x12\x43reateClientOutput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"{\n\x11UpdateClientInput\x12.\n\x05patch\x18\x01 \x03(\x0e\x32\x1f.eolymp.auth.Client.Patch.Field\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12#\n\x06\x63lient\x18\x03 \x01(\x0b\x32\x13.eolymp.auth.Client\"\x14\n\x12UpdateClientOutput\"&\n\x11\x44\x65leteClientInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteClientOutput\"+\n\x16ResetClientSecretInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\")\n\x17ResetClientSecretOutput\x12\x0e\n\x06secret\x18\x01 \x01(\t\"\xdb\x02\n\x13RegisterClientInput\x12\x15\n\rredirect_uris\x18\x01 \x03(\t\x12\"\n\x1atoken_endpoint_auth_method\x18\x02 \x01(\t\x12\x13\n\x0bgrant_types\x18\x03 \x03(\t\x12\x16\n\x0eresponse_types\x18\x04 \x03(\t\x12\x13\n\x0b\x63lient_name\x18\x05 \x01(\t\x12\x12\n\nclient_uri\x18\x06 \x01(\t\x12\x10\n\x08logo_uri\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x10\n\x08\x63ontacts\x18\t \x03(\t\x12\x0f\n\x07tos_uri\x18\n \x01(\t\x12\x12\n\npolicy_uri\x18\x0b \x01(\t\x12\x10\n\x08jwks_uri\x18\x0c \x01(\t\x12\x13\n\x0bsoftware_id\x18\r \x01(\t\x12\x18\n\x10software_version\x18\x0e \x01(\t\x12\x1a\n\x12software_statement\x18\x64 \x01(\t\"\xb8\x04\n\x14RegisterClientOutput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x37\n\x13\x63lient_id_issued_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x18\x63lient_secret_expires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x19registration_access_token\x18\x05 \x01(\t\x12\x1f\n\x17registration_client_uri\x18\x06 \x01(\t\x12\"\n\x1atoken_endpoint_auth_method\x18\x07 \x01(\t\x12\x18\n\x10\x61pplication_type\x18\x08 \x01(\t\x12\x15\n\rredirect_uris\x18\t \x03(\t\x12\x13\n\x0b\x63lient_name\x18\n \x01(\t\x12\x10\n\x08logo_uri\x18\x0b \x01(\t\x12\x14\n\x0csubject_type\x18\x0c \x01(\t\x12\x1d\n\x15sector_identifier_uri\x18\r \x01(\t\x12\x10\n\x08jwks_uri\x18\x0e \x01(\t\x12\'\n\x1fuserinfo_encrypted_response_alg\x18\x0f \x01(\t\x12\'\n\x1fuserinfo_encrypted_response_enc\x18\x10 \x01(\t\x12\x10\n\x08\x63ontacts\x18\x11 \x03(\t\x12\x14\n\x0crequest_uris\x18\x12 \x03(\t2\xc9\x08\n\rClientService\x12\x8a\x01\n\x0bListClients\x12\x1d.eolymp.auth.ListClientsInput\x1a\x1e.eolymp.auth.ListClientsOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x14\x8a\xe3\n\x10\x61uth:client:read\x82\xd3\xe4\x93\x02\x0f\x12\r/auth/clients\x12\x9f\x01\n\x0e\x44\x65scribeClient\x12 .eolymp.auth.DescribeClientInput\x1a!.eolymp.auth.DescribeClientOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x14\x8a\xe3\n\x10\x61uth:client:read\x82\xd3\xe4\x93\x02\x1b\x12\x19/auth/clients/{client_id}\x12\x8e\x01\n\x0c\x43reateClient\x12\x1e.eolymp.auth.CreateClientInput\x1a\x1f.eolymp.auth.CreateClientOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x15\x8a\xe3\n\x11\x61uth:client:write\x82\xd3\xe4\x93\x02\x0f\"\r/auth/clients\x12\x9a\x01\n\x0cUpdateClient\x12\x1e.eolymp.auth.UpdateClientInput\x1a\x1f.eolymp.auth.UpdateClientOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x15\x8a\xe3\n\x11\x61uth:client:write\x82\xd3\xe4\x93\x02\x1b\x1a\x19/auth/clients/{client_id}\x12\x9a\x01\n\x0c\x44\x65leteClient\x12\x1e.eolymp.auth.DeleteClientInput\x1a\x1f.eolymp.auth.DeleteClientOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x15\x8a\xe3\n\x11\x61uth:client:write\x82\xd3\xe4\x93\x02\x1b*\x19/auth/clients/{client_id}\x12\xb6\x01\n\x11ResetClientSecret\x12#.eolymp.auth.ResetClientSecretInput\x1a$.eolymp.auth.ResetClientSecretOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x15\x8a\xe3\n\x11\x61uth:client:write\x82\xd3\xe4\x93\x02(\"&/auth/clients/{client_id}/reset-secret\x12\x84\x01\n\x0eRegisterClient\x12 .eolymp.auth.RegisterClientInput\x1a!.eolymp.auth.RegisterClientOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\"\x16/auth/clients:registerB+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.client_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\024\212\343\n\020auth:client:read\202\323\344\223\002\017\022\r/auth/clients'
  _globals['_CLIENTSERVICE'].methods_by_name['DescribeClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['DescribeClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\024\212\343\n\020auth:client:read\202\323\344\223\002\033\022\031/auth/clients/{client_id}'
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\025\212\343\n\021auth:client:write\202\323\344\223\002\017\"\r/auth/clients'
  _globals['_CLIENTSERVICE'].methods_by_name['UpdateClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['UpdateClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\025\212\343\n\021auth:client:write\202\323\344\223\002\033\032\031/auth/clients/{client_id}'
  _globals['_CLIENTSERVICE'].methods_by_name['DeleteClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['DeleteClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\025\212\343\n\021auth:client:write\202\323\344\223\002\033*\031/auth/clients/{client_id}'
  _globals['_CLIENTSERVICE'].methods_by_name['ResetClientSecret']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['ResetClientSecret']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\025\212\343\n\021auth:client:write\202\323\344\223\002(\"&/auth/clients/{client_id}/reset-secret'
  _globals['_CLIENTSERVICE'].methods_by_name['RegisterClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['RegisterClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\323\344\223\002\030\"\026/auth/clients:register'
  _globals['_LISTCLIENTSINPUT']._serialized_start=207
  _globals['_LISTCLIENTSINPUT']._serialized_end=255
  _globals['_LISTCLIENTSOUTPUT']._serialized_start=257
  _globals['_LISTCLIENTSOUTPUT']._serialized_end=327
  _globals['_DESCRIBECLIENTINPUT']._serialized_start=329
  _globals['_DESCRIBECLIENTINPUT']._serialized_end=369
  _globals['_DESCRIBECLIENTOUTPUT']._serialized_start=371
  _globals['_DESCRIBECLIENTOUTPUT']._serialized_end=430
  _globals['_CREATECLIENTINPUT']._serialized_start=432
  _globals['_CREATECLIENTINPUT']._serialized_end=488
  _globals['_CREATECLIENTOUTPUT']._serialized_start=490
  _globals['_CREATECLIENTOUTPUT']._serialized_end=545
  _globals['_UPDATECLIENTINPUT']._serialized_start=547
  _globals['_UPDATECLIENTINPUT']._serialized_end=670
  _globals['_UPDATECLIENTOUTPUT']._serialized_start=672
  _globals['_UPDATECLIENTOUTPUT']._serialized_end=692
  _globals['_DELETECLIENTINPUT']._serialized_start=694
  _globals['_DELETECLIENTINPUT']._serialized_end=732
  _globals['_DELETECLIENTOUTPUT']._serialized_start=734
  _globals['_DELETECLIENTOUTPUT']._serialized_end=754
  _globals['_RESETCLIENTSECRETINPUT']._serialized_start=756
  _globals['_RESETCLIENTSECRETINPUT']._serialized_end=799
  _globals['_RESETCLIENTSECRETOUTPUT']._serialized_start=801
  _globals['_RESETCLIENTSECRETOUTPUT']._serialized_end=842
  _globals['_REGISTERCLIENTINPUT']._serialized_start=845
  _globals['_REGISTERCLIENTINPUT']._serialized_end=1192
  _globals['_REGISTERCLIENTOUTPUT']._serialized_start=1195
  _globals['_REGISTERCLIENTOUTPUT']._serialized_end=1763
  _globals['_CLIENTSERVICE']._serialized_start=1766
  _globals['_CLIENTSERVICE']._serialized_end=2863
# @@protoc_insertion_point(module_scope)
