# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/space.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/universe/space.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import mcp_pb2 as eolymp_dot_annotations_dot_mcp__pb2
from eolymp.universe import quota_pb2 as eolymp_dot_universe_dot_quota__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/universe/space.proto\x12\x0f\x65olymp.universe\x1a\x1c\x65olymp/annotations/mcp.proto\x1a\x1b\x65olymp/universe/quota.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb2\t\n\x05Space\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x10\n\x08home_url\x18\x32 \x01(\t\x12\x12\n\nissuer_url\x18\x33 \x01(\t\x12\x13\n\x0bgraphql_url\x18\x34 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\r\n\x05image\x18\x0b \x01(\t\x12\x35\n\nvisibility\x18\x0e \x01(\x0e\x32!.eolymp.universe.Space.Visibility\x12\x35\n\x06status\x18\x10 \x01(\x0e\x32\x1d.eolymp.universe.Space.StatusB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x38\n\x08\x66\x65\x61tures\x18\x11 \x03(\x0e\x32\x1e.eolymp.universe.Space.FeatureB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x42\n\x0csubscription\x18\xa0\x06 \x01(\x0b\x32#.eolymp.universe.Space.SubscriptionB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x1b\n\x0b\x61\x66\x66iliation\x18\x0f \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12 \n\x10\x64iscord_guild_id\x18\x12 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x0f\n\x07locales\x18\x13 \x03(\t\x1a\x35\n\x05\x45xtra\",\n\x05\x46ield\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x10\n\x0cSUBSCRIPTION\x10\x01\x1a^\n\x05Patch\"U\n\x05\x46ield\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\x07\n\x03KEY\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\t\n\x05IMAGE\x10\x03\x12\x0e\n\nVISIBILITY\x10\x05\x12\x0b\n\x07LOCALES\x10\x06\x1a\xde\x02\n\x0cSubscription\x12\x0c\n\x04plan\x18\x01 \x01(\t\x12\r\n\x05seats\x18\x02 \x01(\r\x12\r\n\x05usage\x18\x03 \x01(\r\x12\x1b\n\x13usage_based_billing\x18\x05 \x01(\x08\x12%\n\x05quota\x18\n \x01(\x0b\x32\x16.eolymp.universe.Quota\x12\x38\n\x14\x62illing_period_start\x18Z \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12\x62illing_period_end\x18[ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12quota_period_start\x18\\ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10quota_period_end\x18] \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"B\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05TRIAL\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tSUSPENDED\x10\x03\"=\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"t\n\x07\x46\x65\x61ture\x12\x13\n\x0fUNKNOWN_FEATURE\x10\x00\x12\x0c\n\x08PRINTERS\x10\x01\x12\x0f\n\x0bNEWSLETTERS\x10\x02\x12\x12\n\x0eMEMBER_CREDITS\x10\x03\x12\x15\n\x11MERCHANDISE_STORE\x10\x04\x12\n\n\x06RATING\x10\x05\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.space_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_SPACE'].fields_by_name['status']._loaded_options = None
  _globals['_SPACE'].fields_by_name['status']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE'].fields_by_name['features']._loaded_options = None
  _globals['_SPACE'].fields_by_name['features']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE'].fields_by_name['subscription']._loaded_options = None
  _globals['_SPACE'].fields_by_name['subscription']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE'].fields_by_name['affiliation']._loaded_options = None
  _globals['_SPACE'].fields_by_name['affiliation']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE'].fields_by_name['discord_guild_id']._loaded_options = None
  _globals['_SPACE'].fields_by_name['discord_guild_id']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE']._serialized_start=141
  _globals['_SPACE']._serialized_end=1343
  _globals['_SPACE_EXTRA']._serialized_start=592
  _globals['_SPACE_EXTRA']._serialized_end=645
  _globals['_SPACE_EXTRA_FIELD']._serialized_start=601
  _globals['_SPACE_EXTRA_FIELD']._serialized_end=645
  _globals['_SPACE_PATCH']._serialized_start=647
  _globals['_SPACE_PATCH']._serialized_end=741
  _globals['_SPACE_PATCH_FIELD']._serialized_start=656
  _globals['_SPACE_PATCH_FIELD']._serialized_end=741
  _globals['_SPACE_SUBSCRIPTION']._serialized_start=744
  _globals['_SPACE_SUBSCRIPTION']._serialized_end=1094
  _globals['_SPACE_STATUS']._serialized_start=1096
  _globals['_SPACE_STATUS']._serialized_end=1162
  _globals['_SPACE_VISIBILITY']._serialized_start=1164
  _globals['_SPACE_VISIBILITY']._serialized_end=1225
  _globals['_SPACE_FEATURE']._serialized_start=1227
  _globals['_SPACE_FEATURE']._serialized_end=1343
# @@protoc_insertion_point(module_scope)
