# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/member.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/member.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import mcp_pb2 as eolymp_dot_annotations_dot_mcp__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_ghost_pb2 as eolymp_dot_community_dot_member__ghost__pb2
from eolymp.community import member_team_pb2 as eolymp_dot_community_dot_member__team__pb2
from eolymp.community import member_user_pb2 as eolymp_dot_community_dot_member__user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/community/member.proto\x12\x10\x65olymp.community\x1a\x1c\x65olymp/annotations/mcp.proto\x1a eolymp/community/attribute.proto\x1a#eolymp/community/member_ghost.proto\x1a\"eolymp/community/member_team.proto\x1a\"eolymp/community/member_user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xca\r\n\x06Member\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x13\n\x03url\x18\x03 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x14\n\x0c\x65xternal_ref\x18\x04 \x01(\t\x12\x1c\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x14\n\x04rank\x18\x46 \x01(\x05\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x1a\n\nrank_lower\x18H \x01(\x05\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x16\n\x06rating\x18G \x01(\x05\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x15\n\x05level\x18O \x01(\rB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x10\n\x08inactive\x18\x0b \x01(\x08\x12\x12\n\nincomplete\x18\x14 \x01(\x08\x12\x12\n\nunofficial\x18\x1e \x01(\x08\x12\x0e\n\x06secret\x18( \x01(\x08\x12\x37\n\x13\x61\x63tive_period_start\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11\x61\x63tive_period_end\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\ncreated_at\x18< \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x35\n\tseated_at\x18= \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x35\n\tactive_at\x18> \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xa8\xf0\xf0\xe4\x01\x01\x12&\n\x04user\x18\x64 \x01(\x0b\x32\x16.eolymp.community.UserH\x00\x12&\n\x04team\x18\x65 \x01(\x0b\x32\x16.eolymp.community.TeamH\x00\x12(\n\x05ghost\x18\x66 \x01(\x0b\x32\x17.eolymp.community.GhostH\x00\x12\x1c\n\x0crestrictions\x18\n \x03(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x36\n\x05stats\x18\xac\x02 \x01(\x0b\x32\x1e.eolymp.community.Member.StatsB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x0f\n\x06groups\x18\xc8\x01 \x03(\t\x12\x36\n\nattributes\x18\x84\x07 \x03(\x0b\x32!.eolymp.community.Attribute.Value\x12\x39\n\x08metadata\x18\x80\x08 \x03(\x0b\x32&.eolymp.community.Member.MetadataEntry\x1a\x86\x01\n\x05\x45xtra\"}\n\x05\x46ield\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x08\n\x04RANK\x10\x01\x12\t\n\x05STATS\x10\x02\x12\n\n\x06GROUPS\x10\x03\x12\x0e\n\nATTRIBUTES\x10\x04\x12\x0c\n\x08METADATA\x10\x05\x12\x10\n\x0cRESTRICTIONS\x10\x06\x12\x10\n\x0cPRIVATE_DATA\x10\x07\x1a\x9d\x04\n\x05Patch\"\x93\x04\n\x05\x46ield\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\x10\n\x0c\x45XTERNAL_REF\x10\x06\x12\x0c\n\x08INACTIVE\x10\x01\x12\x0e\n\nUNOFFICIAL\x10\x02\x12\x17\n\x13\x41\x43TIVE_PERIOD_START\x10\x07\x12\x15\n\x11\x41\x43TIVE_PERIOD_END\x10\x08\x12\n\n\x06GROUPS\x10\x03\x12\x0e\n\nGROUPS_ADD\x10\x04\x12\x11\n\rGROUPS_REMOVE\x10\x05\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x64\x12\x11\n\rUSER_NICKNAME\x10\x65\x12\x0e\n\nUSER_EMAIL\x10\x66\x12\x11\n\rUSER_PASSWORD\x10g\x12\r\n\tUSER_NAME\x10h\x12\x10\n\x0cUSER_PICTURE\x10i\x12\x11\n\rUSER_BIRTHDAY\x10j\x12\x10\n\x0cUSER_COUNTRY\x10k\x12\r\n\tUSER_CITY\x10l\x12\x14\n\x10USER_PREFERENCES\x10m\x12\x1c\n\x17USER_PREFERENCES_LOCALE\x10\xbe\x01\x12\x1e\n\x19USER_PREFERENCES_TIMEZONE\x10\xbf\x01\x12\x1d\n\x18USER_PREFERENCES_RUNTIME\x10\xc0\x01\x12\x1c\n\x18USER_EMAIL_SUBSCRIPTIONS\x10n\x12\x0e\n\tTEAM_NAME\x10\xc8\x01\x12\x0f\n\nGHOST_NAME\x10\xac\x02\x12\x0f\n\nATTRIBUTES\x10\x84\x07\x12\r\n\x08METADATA\x10\x85\x07\x1ai\n\x05Stats\x12\x0e\n\x06streak\x18\n \x01(\x05\x12\x17\n\x0fproblems_solved\x18\x14 \x01(\x05\x12\x1c\n\x14submissions_accepted\x18\x1e \x01(\x05\x12\x19\n\x11submissions_total\x18) \x01(\x05\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x61\x63\x63ountB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_MEMBER_METADATAENTRY']._loaded_options = None
  _globals['_MEMBER_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_MEMBER'].fields_by_name['id']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['id']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['url']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['url']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['display_name']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['display_name']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['rank']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['rank']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['rank_lower']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['rank_lower']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['rating']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['rating']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['level']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['level']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['created_at']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['created_at']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['seated_at']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['seated_at']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['active_at']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['active_at']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['restrictions']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['restrictions']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['stats']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['stats']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER']._serialized_start=258
  _globals['_MEMBER']._serialized_end=1996
  _globals['_MEMBER_EXTRA']._serialized_start=1151
  _globals['_MEMBER_EXTRA']._serialized_end=1285
  _globals['_MEMBER_EXTRA_FIELD']._serialized_start=1160
  _globals['_MEMBER_EXTRA_FIELD']._serialized_end=1285
  _globals['_MEMBER_PATCH']._serialized_start=1288
  _globals['_MEMBER_PATCH']._serialized_end=1829
  _globals['_MEMBER_PATCH_FIELD']._serialized_start=1298
  _globals['_MEMBER_PATCH_FIELD']._serialized_end=1829
  _globals['_MEMBER_STATS']._serialized_start=1831
  _globals['_MEMBER_STATS']._serialized_end=1936
  _globals['_MEMBER_METADATAENTRY']._serialized_start=1938
  _globals['_MEMBER_METADATAENTRY']._serialized_end=1985
# @@protoc_insertion_point(module_scope)
