# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/invoice.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/invoice.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/vendor/invoice.proto\x12\reolymp.vendor\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x06\n\x07Invoice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\t\x12\x10\n\x08\x63urrency\x18\n \x01(\t\x12-\n\x06status\x18\x0b \x01(\x0e\x32\x1d.eolymp.vendor.Invoice.Status\x12\x15\n\rstatus_reason\x18\x0c \x01(\t\x12\x11\n\tvendor_id\x18\r \x01(\t\x12\x19\n\x11payment_method_id\x18\x0e \x01(\t\x12\x30\n\x0cinvoice_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64ue_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x05lines\x18\x05 \x03(\x0b\x32\x1b.eolymp.vendor.Invoice.Line\x12\x17\n\x0fsubtotal_amount\x18\x06 \x01(\x05\x12\x12\n\ntax_amount\x18\x07 \x01(\x05\x12\x13\n\x0bgrand_total\x18\x08 \x01(\x05\x12\x14\n\x0c\x64ocument_url\x18\t \x01(\t\x12.\n\ncreated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aI\n\x04Line\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x13\n\x0btotal_price\x18\x04 \x01(\x05\x1a|\n\x05Patch\"s\n\x05\x46ield\x12\x11\n\rUNKNOWN_FIELD\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x0c\n\x08\x43URRENCY\x10\x05\x12\x10\n\x0cINVOICE_DATE\x10\x02\x12\x0c\n\x08\x44UE_DATE\x10\x03\x12\t\n\x05LINES\x10\x04\x12\x12\n\x0ePAYMENT_METHOD\x10\x06\"Z\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0c\n\x08\x41PPROVED\x10\x03\x12\x08\n\x04PAID\x10\x04\x12\x0c\n\x08REJECTED\x10\x05\x42/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.invoice_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_INVOICE']._serialized_start=80
  _globals['_INVOICE']._serialized_end=868
  _globals['_INVOICE_LINE']._serialized_start=577
  _globals['_INVOICE_LINE']._serialized_end=650
  _globals['_INVOICE_PATCH']._serialized_start=652
  _globals['_INVOICE_PATCH']._serialized_end=776
  _globals['_INVOICE_PATCH_FIELD']._serialized_start=661
  _globals['_INVOICE_PATCH_FIELD']._serialized_end=776
  _globals['_INVOICE_STATUS']._serialized_start=778
  _globals['_INVOICE_STATUS']._serialized_end=868
# @@protoc_insertion_point(module_scope)
