# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/geolocation/geolocation_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/geolocation/geolocation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,eolymp/geolocation/geolocation_service.proto\x12\x12\x65olymp.geolocation\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"8\n\x12LookupAddressInput\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x8d\x01\n\x13LookupAddressOutput\x12\x10\n\x08latitude\x18\x01 \x01(\x02\x12\x11\n\tlongitude\x18\x02 \x01(\x02\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x10\n\x08timezone\x18\x04 \x01(\t\x12\x10\n\x08postcode\x18\x05 \x01(\t\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x12\x0e\n\x06region\x18\x07 \x01(\t2\xc7\x01\n\x12GeolocationService\x12\xb0\x01\n\rLookupAddress\x12&.eolymp.geolocation.LookupAddressInput\x1a\'.eolymp.geolocation.LookupAddressOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16geolocation:enum:write\x82\xd3\xe4\x93\x02\x1b\x12\x19/geolocation/{ip_address}B9Z7github.com/eolymp/go-sdk/eolymp/geolocation;geolocationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.geolocation.geolocation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/geolocation;geolocation'
  _globals['_GEOLOCATIONSERVICE'].methods_by_name['LookupAddress']._loaded_options = None
  _globals['_GEOLOCATIONSERVICE'].methods_by_name['LookupAddress']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n2\202\343\n\032\212\343\n\026geolocation:enum:write\202\323\344\223\002\033\022\031/geolocation/{ip_address}'
  _globals['_LOOKUPADDRESSINPUT']._serialized_start=167
  _globals['_LOOKUPADDRESSINPUT']._serialized_end=223
  _globals['_LOOKUPADDRESSOUTPUT']._serialized_start=226
  _globals['_LOOKUPADDRESSOUTPUT']._serialized_end=367
  _globals['_GEOLOCATIONSERVICE']._serialized_start=370
  _globals['_GEOLOCATIONSERVICE']._serialized_end=569
# @@protoc_insertion_point(module_scope)
