# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/profile.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/profile.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/vendor/profile.proto\x12\reolymp.vendor\x1a\x1fgoogle/protobuf/timestamp.proto\"\xae\x05\n\x07Profile\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x06status\x18\x02 \x01(\x0e\x32\x1d.eolymp.vendor.Profile.Status\x12\x15\n\rstatus_reason\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\n \x01(\t\x12\x11\n\tlast_name\x18\x0b \x01(\t\x12\x14\n\x0c\x63ompany_name\x18\x10 \x01(\t\x12,\n\x08\x62irthday\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65mail\x18\r \x01(\t\x12\r\n\x05phone\x18\x0e \x01(\t\x12\x0e\n\x06tax_id\x18\x0f \x01(\t\x12\x10\n\x07\x63ountry\x18\xc8\x01 \x01(\t\x12\x0e\n\x05state\x18\xc9\x01 \x01(\t\x12\x14\n\x0bpostal_code\x18\xca\x01 \x01(\t\x12\r\n\x04\x63ity\x18\xcb\x01 \x01(\t\x12\x0e\n\x05line1\x18\xd2\x01 \x01(\t\x12\x0e\n\x05line2\x18\xd3\x01 \x01(\t\x12.\n\ncreated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x93\x01\n\x05Patch\"\x89\x01\n\x05\x46ield\x12\x12\n\x0eUNKNONWN_FIELD\x10\x00\x12\x0e\n\nFIRST_NAME\x10\x01\x12\r\n\tLAST_NAME\x10\x02\x12\x10\n\x0c\x43OMPANY_NAME\x10\x03\x12\x0c\n\x08\x42IRTHDAY\x10\x04\x12\t\n\x05\x45MAIL\x10\x05\x12\t\n\x05PHONE\x10\x06\x12\n\n\x06TAX_ID\x10\x07\x12\x0b\n\x07\x41\x44\x44RESS\x10\x08\"[\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06REVIEW\x10\x02\x12\x0c\n\x08\x41PPROVED\x10\x04\x12\n\n\x06\x41\x43TIVE\x10\x06\x12\x0c\n\x08REJECTED\x10\x05\x42/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.profile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_PROFILE']._serialized_start=80
  _globals['_PROFILE']._serialized_end=766
  _globals['_PROFILE_PATCH']._serialized_start=526
  _globals['_PROFILE_PATCH']._serialized_end=673
  _globals['_PROFILE_PATCH_FIELD']._serialized_start=536
  _globals['_PROFILE_PATCH_FIELD']._serialized_end=673
  _globals['_PROFILE_STATUS']._serialized_start=675
  _globals['_PROFILE_STATUS']._serialized_end=766
# @@protoc_insertion_point(module_scope)
