# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/mail/newsletter_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/mail/newsletter_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.mail import newsletter_pb2 as eolymp_dot_mail_dot_newsletter__pb2
from eolymp.mail import newsletter_recipient_pb2 as eolymp_dot_mail_dot_newsletter__recipient__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/mail/newsletter_service.proto\x12\x0b\x65olymp.mail\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/mail/newsletter.proto\x1a&eolymp/mail/newsletter_recipient.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"D\n\x15\x43reateNewsletterInput\x12+\n\nnewsletter\x18\x01 \x01(\x0b\x32\x17.eolymp.mail.Newsletter\"/\n\x16\x43reateNewsletterOutput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\"\x8f\x01\n\x15UpdateNewsletterInput\x12\x32\n\x05patch\x18\x01 \x03(\x0e\x32#.eolymp.mail.Newsletter.Patch.Field\x12\x15\n\rnewsletter_id\x18\x02 \x01(\t\x12+\n\nnewsletter\x18\x03 \x01(\x0b\x32\x17.eolymp.mail.Newsletter\"\x18\n\x16UpdateNewsletterOutput\".\n\x15\x44\x65leteNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteNewsletterOutput\"e\n\x17\x44\x65scribeNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x33\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32#.eolymp.mail.Newsletter.Extra.Field\"G\n\x18\x44\x65scribeNewsletterOutput\x12+\n\nnewsletter\x18\x01 \x01(\x0b\x32\x17.eolymp.mail.Newsletter\"\xa5\x03\n\x14ListNewslettersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.mail.ListNewslettersInput.Filter\x12\x0e\n\x06search\x18) \x01(\t\x12\x34\n\x04sort\x18\x32 \x01(\x0e\x32&.eolymp.mail.ListNewslettersInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x33\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32#.eolymp.mail.Newsletter.Extra.Field\x1a\x64\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x16\n\x04Sort\x12\x0e\n\nCREATED_AT\x10\x00\"N\n\x15ListNewslettersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.mail.Newsletter\"\xd7\x01\n\x13TestNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12\x44\n\nparameters\x18\x14 \x03(\x0b\x32\x30.eolymp.mail.TestNewsletterInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x16\n\x14TestNewsletterOutput\"B\n\x13SendNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x16\n\x14SendNewsletterOutput\"\x84\x01\n\x18TranslateNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12\x18\n\x10target_automatic\x18\x04 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x05 \x01(\x08\"+\n\x19TranslateNewsletterOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"i\n\x16\x43reateTranslationInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x38\n\x0btranslation\x18\x02 \x01(\x0b\x32#.eolymp.mail.Newsletter.Translation\"1\n\x17\x43reateTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\xb5\x01\n\x16UpdateTranslationInput\x12\x32\n\x05patch\x18\x01 \x03(\x0e\x32#.eolymp.mail.Newsletter.Patch.Field\x12\x15\n\rnewsletter_id\x18\x02 \x01(\t\x12\x16\n\x0etranslation_id\x18\x03 \x01(\t\x12\x38\n\x0btranslation\x18\x04 \x01(\x0b\x32#.eolymp.mail.Newsletter.Translation\"\x19\n\x17UpdateTranslationOutput\"G\n\x16\x44\x65leteTranslationInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"I\n\x18\x44\x65scribeTranslationInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"U\n\x19\x44\x65scribeTranslationOutput\x12\x38\n\x0btranslation\x18\x01 \x01(\x0b\x32#.eolymp.mail.Newsletter.Translation\"\xf0\x01\n\x15ListTranslationsInput\x12\x15\n\rnewsletter_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.mail.ListTranslationsInput.Filter\x1a\x66\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"[\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.eolymp.mail.Newsletter.Translation\"\xba\x01\n\x14\x43reateRecipientInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x0b \x01(\t\x12\x45\n\nparameters\x18\x14 \x03(\x0b\x32\x31.eolymp.mail.CreateRecipientInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x15\x43reateRecipientOutput\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\"\xf2\x01\n\x14ImportRecipientInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x15\n\x0b\x61ll_members\x18\n \x01(\x08H\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12\x14\n\ncontest_id\x18\x0c \x01(\tH\x00\x12\x45\n\nparameters\x18\x14 \x03(\x0b\x32\x31.eolymp.mail.ImportRecipientInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source\"\x17\n\x15ImportRecipientOutput\"C\n\x14\x44\x65leteRecipientInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteRecipientOutput\"\xa0\x02\n\x13ListRecipientsInput\x12\x15\n\rnewsletter_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.mail.ListRecipientsInput.Filter\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\tmember_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"L\n\x14ListRecipientsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.mail.Recipient\"E\n\x16\x44\x65scribeRecipientInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"D\n\x17\x44\x65scribeRecipientOutput\x12)\n\trecipient\x18\x01 \x01(\x0b\x32\x16.eolymp.mail.Recipient2\xff\x1a\n\x11NewsletterService\x12\xa3\x01\n\x10\x43reateNewsletter\x12\".eolymp.mail.CreateNewsletterInput\x1a#.eolymp.mail.CreateNewsletterOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/newsletters\x12\xb3\x01\n\x10UpdateNewsletter\x12\".eolymp.mail.UpdateNewsletterInput\x1a#.eolymp.mail.UpdateNewsletterOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/newsletters/{newsletter_id}\x12\xb3\x01\n\x10\x44\x65leteNewsletter\x12\".eolymp.mail.DeleteNewsletterInput\x1a#.eolymp.mail.DeleteNewsletterOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1e*\x1c/newsletters/{newsletter_id}\x12\x97\x01\n\x12\x44\x65scribeNewsletter\x12$.eolymp.mail.DescribeNewsletterInput\x1a%.eolymp.mail.DescribeNewsletterOutput\"4\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x1e\x12\x1c/newsletters/{newsletter_id}\x12}\n\x0fListNewsletters\x12!.eolymp.mail.ListNewslettersInput\x1a\".eolymp.mail.ListNewslettersOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/newsletters\x12\xb2\x01\n\x0eTestNewsletter\x12 .eolymp.mail.TestNewsletterInput\x1a!.eolymp.mail.TestNewsletterOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02#\"!/newsletters/{newsletter_id}/test\x12\xb2\x01\n\x0eSendNewsletter\x12 .eolymp.mail.SendNewsletterInput\x1a!.eolymp.mail.SendNewsletterOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02#\"!/newsletters/{newsletter_id}/send\x12\xc6\x01\n\x13TranslateNewsletter\x12%.eolymp.mail.TranslateNewsletterInput\x1a&.eolymp.mail.TranslateNewsletterOutput\"`\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02(\"&/newsletters/{newsletter_id}/translate\x12\xc3\x01\n\x11\x43reateTranslation\x12#.eolymp.mail.CreateTranslationInput\x1a$.eolymp.mail.CreateTranslationOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02+\")/newsletters/{newsletter_id}/translations\x12\xd4\x01\n\x11UpdateTranslation\x12#.eolymp.mail.UpdateTranslationInput\x1a$.eolymp.mail.UpdateTranslationOutput\"t\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02<\x1a:/newsletters/{newsletter_id}/translations/{translation_id}\x12\xd4\x01\n\x11\x44\x65leteTranslation\x12#.eolymp.mail.DeleteTranslationInput\x1a$.eolymp.mail.DeleteTranslationOutput\"t\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02<*:/newsletters/{newsletter_id}/translations/{translation_id}\x12\xda\x01\n\x13\x44\x65scribeTranslation\x12%.eolymp.mail.DescribeTranslationInput\x1a&.eolymp.mail.DescribeTranslationOutput\"t\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1e\x8a\xe3\n\x1anewsletter:newsletter:read\x82\xd3\xe4\x93\x02<\x12:/newsletters/{newsletter_id}/translations/{translation_id}\x12\xbf\x01\n\x10ListTranslations\x12\".eolymp.mail.ListTranslationsInput\x1a#.eolymp.mail.ListTranslationsOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1e\x8a\xe3\n\x1anewsletter:newsletter:read\x82\xd3\xe4\x93\x02+\x12)/newsletters/{newsletter_id}/translations\x12\xbb\x01\n\x0f\x43reateRecipient\x12!.eolymp.mail.CreateRecipientInput\x1a\".eolymp.mail.CreateRecipientOutput\"a\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02)\"\'/newsletters/{newsletter_id}/recipients\x12\xc2\x01\n\x0fImportRecipient\x12!.eolymp.mail.ImportRecipientInput\x1a\".eolymp.mail.ImportRecipientOutput\"h\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x30\"./newsletters/{newsletter_id}/recipients:import\x12\xca\x01\n\x0f\x44\x65leteRecipient\x12!.eolymp.mail.DeleteRecipientInput\x1a\".eolymp.mail.DeleteRecipientOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x38*6/newsletters/{newsletter_id}/recipients/{recipient_id}\x12\xb8\x01\n\x0eListRecipients\x12 .eolymp.mail.ListRecipientsInput\x1a!.eolymp.mail.ListRecipientsOutput\"a\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02)\x12\'/newsletters/{newsletter_id}/recipients\x12\xd0\x01\n\x11\x44\x65scribeRecipient\x12#.eolymp.mail.DescribeRecipientInput\x1a$.eolymp.mail.DescribeRecipientOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x38\x12\x36/newsletters/{newsletter_id}/recipients/{recipient_id}\x1a\x1b\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.SpaceB+Z)github.com/eolymp/go-sdk/eolymp/mail;mailb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.mail.newsletter_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/mail;mail'
  _globals['_TESTNEWSLETTERINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_TESTNEWSLETTERINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_NEWSLETTERSERVICE']._loaded_options = None
  _globals['_NEWSLETTERSERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\016\"\014/newsletters'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['UpdateNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['UpdateNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\036\032\034/newsletters/{newsletter_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\036*\034/newsletters/{newsletter_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeNewsletter']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\036\022\034/newsletters/{newsletter_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListNewsletters']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListNewsletters']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/newsletters'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['TestNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['TestNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002#\"!/newsletters/{newsletter_id}/test'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['SendNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['SendNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002#\"!/newsletters/{newsletter_id}/send'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['TranslateNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['TranslateNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002(\"&/newsletters/{newsletter_id}/translate'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateTranslation']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002+\")/newsletters/{newsletter_id}/translations'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['UpdateTranslation']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['UpdateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002<\032:/newsletters/{newsletter_id}/translations/{translation_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteTranslation']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002<*:/newsletters/{newsletter_id}/translations/{translation_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeTranslation']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\036\212\343\n\032newsletter:newsletter:read\202\323\344\223\002<\022:/newsletters/{newsletter_id}/translations/{translation_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListTranslations']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\036\212\343\n\032newsletter:newsletter:read\202\323\344\223\002+\022)/newsletters/{newsletter_id}/translations'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateRecipient']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002)\"\'/newsletters/{newsletter_id}/recipients'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ImportRecipient']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ImportRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0020\"./newsletters/{newsletter_id}/recipients:import'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteRecipient']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0028*6/newsletters/{newsletter_id}/recipients/{recipient_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListRecipients']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListRecipients']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002)\022\'/newsletters/{newsletter_id}/recipients'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeRecipient']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0028\0226/newsletters/{newsletter_id}/recipients/{recipient_id}'
  _globals['_CREATENEWSLETTERINPUT']._serialized_start=327
  _globals['_CREATENEWSLETTERINPUT']._serialized_end=395
  _globals['_CREATENEWSLETTEROUTPUT']._serialized_start=397
  _globals['_CREATENEWSLETTEROUTPUT']._serialized_end=444
  _globals['_UPDATENEWSLETTERINPUT']._serialized_start=447
  _globals['_UPDATENEWSLETTERINPUT']._serialized_end=590
  _globals['_UPDATENEWSLETTEROUTPUT']._serialized_start=592
  _globals['_UPDATENEWSLETTEROUTPUT']._serialized_end=616
  _globals['_DELETENEWSLETTERINPUT']._serialized_start=618
  _globals['_DELETENEWSLETTERINPUT']._serialized_end=664
  _globals['_DELETENEWSLETTEROUTPUT']._serialized_start=666
  _globals['_DELETENEWSLETTEROUTPUT']._serialized_end=690
  _globals['_DESCRIBENEWSLETTERINPUT']._serialized_start=692
  _globals['_DESCRIBENEWSLETTERINPUT']._serialized_end=793
  _globals['_DESCRIBENEWSLETTEROUTPUT']._serialized_start=795
  _globals['_DESCRIBENEWSLETTEROUTPUT']._serialized_end=866
  _globals['_LISTNEWSLETTERSINPUT']._serialized_start=869
  _globals['_LISTNEWSLETTERSINPUT']._serialized_end=1290
  _globals['_LISTNEWSLETTERSINPUT_FILTER']._serialized_start=1166
  _globals['_LISTNEWSLETTERSINPUT_FILTER']._serialized_end=1266
  _globals['_LISTNEWSLETTERSINPUT_SORT']._serialized_start=1268
  _globals['_LISTNEWSLETTERSINPUT_SORT']._serialized_end=1290
  _globals['_LISTNEWSLETTERSOUTPUT']._serialized_start=1292
  _globals['_LISTNEWSLETTERSOUTPUT']._serialized_end=1370
  _globals['_TESTNEWSLETTERINPUT']._serialized_start=1373
  _globals['_TESTNEWSLETTERINPUT']._serialized_end=1588
  _globals['_TESTNEWSLETTERINPUT_PARAMETERSENTRY']._serialized_start=1539
  _globals['_TESTNEWSLETTERINPUT_PARAMETERSENTRY']._serialized_end=1588
  _globals['_TESTNEWSLETTEROUTPUT']._serialized_start=1590
  _globals['_TESTNEWSLETTEROUTPUT']._serialized_end=1612
  _globals['_SENDNEWSLETTERINPUT']._serialized_start=1614
  _globals['_SENDNEWSLETTERINPUT']._serialized_end=1680
  _globals['_SENDNEWSLETTEROUTPUT']._serialized_start=1682
  _globals['_SENDNEWSLETTEROUTPUT']._serialized_end=1704
  _globals['_TRANSLATENEWSLETTERINPUT']._serialized_start=1707
  _globals['_TRANSLATENEWSLETTERINPUT']._serialized_end=1839
  _globals['_TRANSLATENEWSLETTEROUTPUT']._serialized_start=1841
  _globals['_TRANSLATENEWSLETTEROUTPUT']._serialized_end=1884
  _globals['_CREATETRANSLATIONINPUT']._serialized_start=1886
  _globals['_CREATETRANSLATIONINPUT']._serialized_end=1991
  _globals['_CREATETRANSLATIONOUTPUT']._serialized_start=1993
  _globals['_CREATETRANSLATIONOUTPUT']._serialized_end=2042
  _globals['_UPDATETRANSLATIONINPUT']._serialized_start=2045
  _globals['_UPDATETRANSLATIONINPUT']._serialized_end=2226
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_start=2228
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_end=2253
  _globals['_DELETETRANSLATIONINPUT']._serialized_start=2255
  _globals['_DELETETRANSLATIONINPUT']._serialized_end=2326
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_start=2328
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_end=2353
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_start=2355
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_end=2428
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_start=2430
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_end=2515
  _globals['_LISTTRANSLATIONSINPUT']._serialized_start=2518
  _globals['_LISTTRANSLATIONSINPUT']._serialized_end=2758
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_start=2656
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_end=2758
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_start=2760
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_end=2851
  _globals['_CREATERECIPIENTINPUT']._serialized_start=2854
  _globals['_CREATERECIPIENTINPUT']._serialized_end=3040
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_start=1539
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_end=1588
  _globals['_CREATERECIPIENTOUTPUT']._serialized_start=3042
  _globals['_CREATERECIPIENTOUTPUT']._serialized_end=3087
  _globals['_IMPORTRECIPIENTINPUT']._serialized_start=3090
  _globals['_IMPORTRECIPIENTINPUT']._serialized_end=3332
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_start=1539
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_end=1588
  _globals['_IMPORTRECIPIENTOUTPUT']._serialized_start=3334
  _globals['_IMPORTRECIPIENTOUTPUT']._serialized_end=3357
  _globals['_DELETERECIPIENTINPUT']._serialized_start=3359
  _globals['_DELETERECIPIENTINPUT']._serialized_end=3426
  _globals['_DELETERECIPIENTOUTPUT']._serialized_start=3428
  _globals['_DELETERECIPIENTOUTPUT']._serialized_end=3451
  _globals['_LISTRECIPIENTSINPUT']._serialized_start=3454
  _globals['_LISTRECIPIENTSINPUT']._serialized_end=3742
  _globals['_LISTRECIPIENTSINPUT_FILTER']._serialized_start=3589
  _globals['_LISTRECIPIENTSINPUT_FILTER']._serialized_end=3742
  _globals['_LISTRECIPIENTSOUTPUT']._serialized_start=3744
  _globals['_LISTRECIPIENTSOUTPUT']._serialized_end=3820
  _globals['_DESCRIBERECIPIENTINPUT']._serialized_start=3822
  _globals['_DESCRIBERECIPIENTINPUT']._serialized_end=3891
  _globals['_DESCRIBERECIPIENTOUTPUT']._serialized_start=3893
  _globals['_DESCRIBERECIPIENTOUTPUT']._serialized_end=3961
  _globals['_NEWSLETTERSERVICE']._serialized_start=3964
  _globals['_NEWSLETTERSERVICE']._serialized_end=7419
# @@protoc_insertion_point(module_scope)
