# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/invoice_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/invoice_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.vendor import invoice_pb2 as eolymp_dot_vendor_dot_invoice__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/vendor/invoice_service.proto\x12\reolymp.vendor\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/vendor/invoice.proto\x1a!eolymp/wellknown/expression.proto\"\xca\x02\n\x11ListInvoicesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.vendor.ListInvoicesInput.Filter\x1a\xcd\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\x06number\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\tvendor_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"J\n\x12ListInvoicesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.vendor.Invoice\"*\n\x14\x44\x65scribeInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"@\n\x15\x44\x65scribeInvoiceOutput\x12\'\n\x07invoice\x18\x01 \x01(\x0b\x32\x16.eolymp.vendor.Invoice\"=\n\x12\x43reateInvoiceInput\x12\'\n\x07invoice\x18\x01 \x01(\x0b\x32\x16.eolymp.vendor.Invoice\")\n\x13\x43reateInvoiceOutput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"\x84\x01\n\x12UpdateInvoiceInput\x12\x31\n\x05patch\x18\x01 \x03(\x0e\x32\".eolymp.vendor.Invoice.Patch.Field\x12\x12\n\ninvoice_id\x18\x02 \x01(\t\x12\'\n\x07invoice\x18\x03 \x01(\x0b\x32\x16.eolymp.vendor.Invoice\"\x15\n\x13UpdateInvoiceOutput\"(\n\x12\x44\x65leteInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteInvoiceOutput\"P\n\x1aUploadInvoiceDocumentInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"3\n\x1bUploadInvoiceDocumentOutput\x12\x14\n\x0c\x64ocument_url\x18\x01 \x01(\t\":\n\x13\x41pproveInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x16\n\x14\x41pproveInvoiceOutput\"(\n\x12SubmitInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"\x15\n\x13SubmitInvoiceOutput\"9\n\x12RejectInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x15\n\x13RejectInvoiceOutput2\xbb\x0c\n\x0eInvoiceService\x12\x97\x01\n\x0cListInvoices\x12 .eolymp.vendor.ListInvoicesInput\x1a!.eolymp.vendor.ListInvoicesOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02\x12\x12\x10/vendor/invoices\x12\xad\x01\n\x0f\x44\x65scribeInvoice\x12#.eolymp.vendor.DescribeInvoiceInput\x1a$.eolymp.vendor.DescribeInvoiceOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/vendor/invoices/{invoice_id}\x12\x9b\x01\n\rCreateInvoice\x12!.eolymp.vendor.CreateInvoiceInput\x1a\".eolymp.vendor.CreateInvoiceOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x12\"\x10/vendor/invoices\x12\xa8\x01\n\rUpdateInvoice\x12!.eolymp.vendor.UpdateInvoiceInput\x1a\".eolymp.vendor.UpdateInvoiceOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/vendor/invoices/{invoice_id}\x12\xa8\x01\n\rDeleteInvoice\x12!.eolymp.vendor.DeleteInvoiceInput\x1a\".eolymp.vendor.DeleteInvoiceOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x1f*\x1d/vendor/invoices/{invoice_id}\x12\xd0\x01\n\x15UploadInvoiceDocument\x12).eolymp.vendor.UploadInvoiceDocumentInput\x1a*.eolymp.vendor.UploadInvoiceDocumentOutput\"`\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02/\"&/vendor/invoices/{invoice_id}/document\x98\xe3\n\x80\x80\x80\x01\x12\xaf\x01\n\rSubmitInvoice\x12!.eolymp.vendor.SubmitInvoiceInput\x1a\".eolymp.vendor.SubmitInvoiceOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02&\"$/vendor/invoices/{invoice_id}/submit\x12\xb3\x01\n\x0e\x41pproveInvoice\x12\".eolymp.vendor.ApproveInvoiceInput\x1a#.eolymp.vendor.ApproveInvoiceOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\'\"%/vendor/invoices/{invoice_id}/approve\x12\xaf\x01\n\rRejectInvoice\x12!.eolymp.vendor.RejectInvoiceInput\x1a\".eolymp.vendor.RejectInvoiceOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02&\"$/vendor/invoices/{invoice_id}/rejectB/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.invoice_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_INVOICESERVICE'].methods_by_name['ListInvoices']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['ListInvoices']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002\022\022\020/vendor/invoices'
  _globals['_INVOICESERVICE'].methods_by_name['DescribeInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['DescribeInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002\037\022\035/vendor/invoices/{invoice_id}'
  _globals['_INVOICESERVICE'].methods_by_name['CreateInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['CreateInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\022\"\020/vendor/invoices'
  _globals['_INVOICESERVICE'].methods_by_name['UpdateInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['UpdateInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\037\032\035/vendor/invoices/{invoice_id}'
  _globals['_INVOICESERVICE'].methods_by_name['DeleteInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['DeleteInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\037*\035/vendor/invoices/{invoice_id}'
  _globals['_INVOICESERVICE'].methods_by_name['UploadInvoiceDocument']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['UploadInvoiceDocument']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002/\"&/vendor/invoices/{invoice_id}/document\230\343\n\200\200\200\001'
  _globals['_INVOICESERVICE'].methods_by_name['SubmitInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['SubmitInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002&\"$/vendor/invoices/{invoice_id}/submit'
  _globals['_INVOICESERVICE'].methods_by_name['ApproveInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['ApproveInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\'\"%/vendor/invoices/{invoice_id}/approve'
  _globals['_INVOICESERVICE'].methods_by_name['RejectInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['RejectInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002&\"$/vendor/invoices/{invoice_id}/reject'
  _globals['_LISTINVOICESINPUT']._serialized_start=218
  _globals['_LISTINVOICESINPUT']._serialized_end=548
  _globals['_LISTINVOICESINPUT_FILTER']._serialized_start=343
  _globals['_LISTINVOICESINPUT_FILTER']._serialized_end=548
  _globals['_LISTINVOICESOUTPUT']._serialized_start=550
  _globals['_LISTINVOICESOUTPUT']._serialized_end=624
  _globals['_DESCRIBEINVOICEINPUT']._serialized_start=626
  _globals['_DESCRIBEINVOICEINPUT']._serialized_end=668
  _globals['_DESCRIBEINVOICEOUTPUT']._serialized_start=670
  _globals['_DESCRIBEINVOICEOUTPUT']._serialized_end=734
  _globals['_CREATEINVOICEINPUT']._serialized_start=736
  _globals['_CREATEINVOICEINPUT']._serialized_end=797
  _globals['_CREATEINVOICEOUTPUT']._serialized_start=799
  _globals['_CREATEINVOICEOUTPUT']._serialized_end=840
  _globals['_UPDATEINVOICEINPUT']._serialized_start=843
  _globals['_UPDATEINVOICEINPUT']._serialized_end=975
  _globals['_UPDATEINVOICEOUTPUT']._serialized_start=977
  _globals['_UPDATEINVOICEOUTPUT']._serialized_end=998
  _globals['_DELETEINVOICEINPUT']._serialized_start=1000
  _globals['_DELETEINVOICEINPUT']._serialized_end=1040
  _globals['_DELETEINVOICEOUTPUT']._serialized_start=1042
  _globals['_DELETEINVOICEOUTPUT']._serialized_end=1063
  _globals['_UPLOADINVOICEDOCUMENTINPUT']._serialized_start=1065
  _globals['_UPLOADINVOICEDOCUMENTINPUT']._serialized_end=1145
  _globals['_UPLOADINVOICEDOCUMENTOUTPUT']._serialized_start=1147
  _globals['_UPLOADINVOICEDOCUMENTOUTPUT']._serialized_end=1198
  _globals['_APPROVEINVOICEINPUT']._serialized_start=1200
  _globals['_APPROVEINVOICEINPUT']._serialized_end=1258
  _globals['_APPROVEINVOICEOUTPUT']._serialized_start=1260
  _globals['_APPROVEINVOICEOUTPUT']._serialized_end=1282
  _globals['_SUBMITINVOICEINPUT']._serialized_start=1284
  _globals['_SUBMITINVOICEINPUT']._serialized_end=1324
  _globals['_SUBMITINVOICEOUTPUT']._serialized_start=1326
  _globals['_SUBMITINVOICEOUTPUT']._serialized_end=1347
  _globals['_REJECTINVOICEINPUT']._serialized_start=1349
  _globals['_REJECTINVOICEINPUT']._serialized_end=1406
  _globals['_REJECTINVOICEOUTPUT']._serialized_start=1408
  _globals['_REJECTINVOICEOUTPUT']._serialized_end=1429
  _globals['_INVOICESERVICE']._serialized_start=1432
  _globals['_INVOICESERVICE']._serialized_end=3027
# @@protoc_insertion_point(module_scope)
