from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
MCP_VALUE_DESC_FIELD_NUMBER: _ClassVar[int]
mcp_value_desc: _descriptor.FieldDescriptor
MCP_VALUE_IGNORE_FIELD_NUMBER: _ClassVar[int]
mcp_value_ignore: _descriptor.FieldDescriptor
MCP_FIELD_DESC_FIELD_NUMBER: _ClassVar[int]
mcp_field_desc: _descriptor.FieldDescriptor
MCP_FIELD_IGNORE_FIELD_NUMBER: _ClassVar[int]
mcp_field_ignore: _descriptor.FieldDescriptor
READ_ONLY_FIELD_NUMBER: _ClassVar[int]
read_only: _descriptor.FieldDescriptor
MCP_TOOL_DESC_FIELD_NUMBER: _ClassVar[int]
mcp_tool_desc: _descriptor.FieldDescriptor
